@@ -1,4 +1,5 @@
 #include <QDeclarativeContext>
+#include <QDeclarativeEngine>
 #include <QtGui/QApplication>
 #include "qmlapplicationviewer.h"
 #include "windowhelper.h"
@@ -39,10 +40,11 @@ int main(int argc, char *argv[])
     FileHandler *fileHandler = new FileHandler();
     viewer.rootContext()->setContextProperty("fileHandler", fileHandler);
 
-//    NetworkHelper *nwHelper = new NetworkHelper();
-//    QNetworkAccessManager *manager = new QNetworkAccessManager();
-//    nwHelper->setNetworkAccessManager(manager);
-//    nwHelper->doWebRequest("", "POST", "https://www.google.com/accounts/ClientLogin?Email=&Passwd=", 1);
+    // Share QML NetworkAccessManger for QT C++ network operations
+    NetworkHelper *nwHelper = new NetworkHelper();
+    QNetworkAccessManager * manager = viewer.rootContext()->engine()->networkAccessManager();
+    nwHelper->setNetworkAccessManager(manager);
+    //nwHelper->doWebRequest("POST", "https://www.google.com/accounts/ClientLogin?Email=&Passwd=", 0);
 
     // C++ ListModel
     //    viewer.rootContext()->setContextProperty("pfoCModel",  createPfoModel);
