@@ -10,17 +10,26 @@ void NetworkHelper::setNetworkAccessManager(QNetworkAccessManager *manager) {
 }
 
 // doWebRequest in C++
-void NetworkHelper::doWebRequest(QString sid, QString method, QString itemURL, int params) {
+int NetworkHelper::doWebRequest(QString method, QString itemURL, int params) {
     QNetworkRequest request;
     request.setUrl(QUrl(itemURL));
 
-    if (params==1) {
+    /*
+     params
+       0: Google Auth, encrypted
+       1: Google Query with auth key
+       2: Yahoo Query
+    */
+
+    if (params==0) {
         request.setAttribute(QNetworkRequest::ConnectionEncryptedAttribute, true);
         request.setRawHeader("Content-Type", "application/x-www-form-urlencoded");
     }
 
-    if(sid.length()>0 && params<2) {
-        //request.setRawHeader("Authorization", "GoogleLogin auth=" + sid);
+    if(auth.length()>0 && params<2) {
+        QByteArray gAuth = "GoogleLogin auth=";
+        gAuth.append(auth);
+        request.setRawHeader("Authorization", gAuth);
         request.setRawHeader("GData-Version", "2");
     }
 
@@ -29,6 +38,8 @@ void NetworkHelper::doWebRequest(QString sid, QString method, QString itemURL, i
         qDebug() << "QNetworkManager: GET" << itemURL;
         #endif
         reply = nam->get(request);
+
+        connect(reply, SIGNAL(readyRead()), this, SLOT(parseAuth()));
     }
     // This is for login only
     else if (method=="POST") {
@@ -66,9 +77,9 @@ void NetworkHelper::doWebRequest(QString sid, QString method, QString itemURL, i
         connect(reply, SIGNAL(readyRead()), this, SLOT(parseAuth()));
         //connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
         //        this, SLOT(slotError(QNetworkReply::NetworkError)));
-        //connect(reply, SIGNAL(sslErrors(QList<QSslError>)),
-        //        this, SLOT(slotSslErrors(QList<QSslError>)));
     }
+
+    return 0;
 }
 
 void NetworkHelper::parseAuth() {
@@ -101,6 +112,8 @@ void NetworkHelper::parseAuth() {
     qDebug() << "######" << auth;
     #endif
 
+    emit statusChanged("completed");
+
     // XML
     // - parsePfo()
     // - parsePos()
