@@ -13,7 +13,7 @@
 #include <QIODevice>
 #include <QByteArray>
 
-//#define DBG
+#define DBG
 
 class QNetworkAccessManager;
 class QNetworkReply;
@@ -30,7 +30,7 @@ public:
     explicit NetworkHelper(QObject *parent = 0);
 
     void setNetworkAccessManager(QNetworkAccessManager *manager);
-    void doWebRequest(QString sid, QString method, QString itemURL, int params);
+    int doWebRequest(QString method, QString itemURL, int params);
 
 
 signals:
