@@ -301,8 +301,13 @@ function loadAllPortfolios() {
 
 function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
 
+    // activePos is not set upon first entry
+    if (activePos=="") {
+        activePos = "https://finance.google.com/finance/feeds/default/portfolios/1/positions";
+    }
+
     // Replace http with https
-    posFeedLink = posFeedLink.replace("http", "https");
+    posFeedLink = posFeedLink.replace("http:", "https:");
 
     console.log("loadOnePosition: " + posFeedLink + " " + pfoLocal + " " + pfoIsYahoo + " " + loadPosFromFile);
 
